==> webbase-5.10.0.tar.gz: webbase-5.10.0/hooks/WebbaseHookMifluz.h <==
/*
 *   Copyright (C) 1997, 1998, 1999 Loic Dachary
 *
 *   This program is free software; you can redistribute it and/or modify it
 *   under the terms of the GNU General Public License as published by the
 *   Free Software Foundation; either version 2, or (at your option) any
 *   later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, 675 Mass Ave, Cambridge, MA 02139, USA. 
 *
 */
#ifdef HAVE_MIFLUZ_H

#ifndef _WebbaseHookMifluz_h
#define _WebbaseHookMifluz_h

#include <WebbaseHook.h>
#include <mifluz.h>

class WebbaseHookMifluz : public WebbaseHook {
 public:
  WebbaseHookMifluz();
  virtual ~WebbaseHookMifluz();

  //
  // WebbaseGetopt virtuals
  //
  virtual struct option* Options();
  virtual int HandleOption(struct option* option);

  //
  // Hook interface
  //
  virtual int Init(webbase_t* base);
  virtual int Ok(webbase_url_t* webbase_url);
  virtual int Insert(webbase_url_t* webbase_url);
  virtual int InsertWatch();
  virtual int Update(webbase_url_t* webbase_url);
  virtual int Delete(webbase_url_t* webbase_url);
  virtual int DeleteId(int id, char* url, int url_length);
  virtual int RehookStart();
  virtual int RehookEnd();
  virtual int RebuildStart();
  virtual int RebuildEnd();
  virtual void InfoSet(char* info);
  virtual void Server(int server);
  virtual void End();

  //
  // Mifluz implementation
  //
  int Open(int flags);
  int Close();
  char* Database() const;
  int  InsertChunk(int info, html_content_parsed_t* parsed);
  int  InsertContent(const char* buffer, int buffer_length);

  Configuration* config;
  WordReference* wordRef;
  WordList* inv;
};

#endif /* _WebbaseHookMifluz_h */

#endif /* HAVE_MIFLUZ_H */

==> webbase-5.12.0.tar.gz: webbase-5.12.0/hooks/WebbaseHookMifluz.h <==
/*
 *   Copyright (C) 1997, 1998, 1999 Loic Dachary
 *
 *   This program is free software; you can redistribute it and/or modify it
 *   under the terms of the GNU General Public License as published by the
 *   Free Software Foundation; either version 2, or (at your option) any
 *   later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, 675 Mass Ave, Cambridge, MA 02139, USA. 
 *
 */
#ifdef HAVE_MIFLUZ_H

#ifndef _WebbaseHookMifluz_h
#define _WebbaseHookMifluz_h

#include <WebbaseHook.h>
#include <mifluz.h>

class WebbaseHookMifluz : public WebbaseHook {
 public:
  WebbaseHookMifluz();
  virtual ~WebbaseHookMifluz();

  //
  // WebbaseGetopt virtuals
  //
  virtual struct option* Options();
  virtual void Parse(int argc, char** argv);
  virtual int HandleOption(struct option* option);

  //
  // Hook interface
  //
  virtual int Init(webbase_t* base);
  virtual int Ok(webbase_url_t* webbase_url);
  virtual int Insert(webbase_url_t* webbase_url);
  virtual int InsertWatch();
  virtual int Update(webbase_url_t* webbase_url);
  virtual int Delete(webbase_url_t* webbase_url);
  virtual int DeleteId(int id, char* url, int url_length);
  virtual int RehookStart();
  virtual int RehookEnd();
  virtual int RebuildStart();
  virtual int RebuildEnd();
  virtual void InfoSet(char* info);
  virtual void Server(int server);
  virtual void End();

  //
  // Mifluz implementation
  //
  int Open(int flags);
  int Close();
  const char* Database() const;
  int  InsertChunk(int info, html_content_parsed_t* parsed);
  int  InsertContent(const char* buffer, int buffer_length);

  WordContext* context;
  WordReference* wordRef;
  WordList* inv;
  String index_dir;
  String index_base;
  String index_config;
  String cache_size;
  String page_size;
  String compress;
};

#endif /* _WebbaseHookMifluz_h */

#endif /* HAVE_MIFLUZ_H */
